Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(230)

Unified Diff: chrome/browser/autocomplete/autocomplete.cc

Issue 5384002: net: Remove typedef net::URLRequest URLRequest; (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: review Created 10 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/autocomplete/autocomplete.cc
diff --git a/chrome/browser/autocomplete/autocomplete.cc b/chrome/browser/autocomplete/autocomplete.cc
index 01d36fa3250465e3fb9e4914b5e126bf3cba308c..66a91a6fb264db9d244081fb964a51a0ff2b6f57 100644
--- a/chrome/browser/autocomplete/autocomplete.cc
+++ b/chrome/browser/autocomplete/autocomplete.cc
@@ -148,13 +148,13 @@ AutocompleteInput::Type AutocompleteInput::Parse(
if (parts->scheme.is_nonempty() &&
(parsed_scheme != L"http") && (parsed_scheme != L"https")) {
// See if we know how to handle the URL internally.
- if (URLRequest::IsHandledProtocol(WideToASCII(parsed_scheme)))
+ if (net::URLRequest::IsHandledProtocol(WideToASCII(parsed_scheme)))
return URL;
// There are also some schemes that we convert to other things before they
// reach the renderer or else the renderer handles internally without
// reaching the URLRequest logic. We thus won't catch these above, but we
// should still claim to handle them.
if (LowerCaseEqualsASCII(parsed_scheme, chrome::kViewSourceScheme) ||
LowerCaseEqualsASCII(parsed_scheme, chrome::kJavaScriptScheme) ||
LowerCaseEqualsASCII(parsed_scheme, chrome::kDataScheme))
@@ -148,13 +148,13 @@ AutocompleteInput::Type AutocompleteInput::Parse(
// There are also some schemes that we convert to other things before they
// reach the renderer or else the renderer handles internally without
- // reaching the URLRequest logic. We thus won't catch these above, but we
- // should still claim to handle them.
+ // reaching the net::URLRequest logic. We thus won't catch these above, but
+ // we should still claim to handle them.
if (LowerCaseEqualsASCII(parsed_scheme, chrome::kViewSourceScheme) ||
LowerCaseEqualsASCII(parsed_scheme, chrome::kJavaScriptScheme) ||

Powered by Google App Engine
This is Rietveld 408576698